@@ -28,19 +28,6 @@ logging.basicConfig(format='%(levelname)s (%(name)s %(lineno)s): %(message)s')
 logger.setLevel(logging.INFO)
 
 
-INPUT_METADATA_HT_NAME = 'input_metadata.ht'
-HAIL_SAMPLE_QC_HT_NAME = 'hail_sample_qc.ht'
-NONGNOMAD_SNPS_HT_NAME = 'nongnomad_snps.ht'
-HARD_FILTERED_SAMPLES_HT_NAME = 'hard_filtered_samples.ht'
-SEX_HT_NAME = 'sex.ht'
-POP_HT_NAME = 'pop.ht'
-REGRESSED_METRICS_HT_NAME = 'regressed_metrics.ht'
-RELATED_SAMPLES_TO_DROP_HT_NAME = 'related_samples_to_drop.ht'
-PCA_EIGENVALUES_HT_NAME = 'pca_eigenvalues.ht'
-PCA_SCORES_HT_NAME = 'pca_scores.ht'
-PCA_LOADINGS_HT_NAME = 'pca_loadings.ht'
-
-
 def compute_hail_sample_qc(
     mt: hl.MatrixTable,
     tmp_bucket: str,
@@ -182,7 +169,7 @@ def infer_sex(
 
 def run_pca_ancestry_analysis(
     mt: hl.MatrixTable,
-    sample_to_drop_ht: hl.Table,
+    sample_to_drop_ht: Optional[hl.Table],
     tmp_bucket: str,
     n_pcs: int,
     out_eigenvalues_ht_path: Optional[str] = None,
@@ -218,7 +205,8 @@ def run_pca_ancestry_analysis(
 
     # Adjusting the number of principal components not to exceed the
     # number of samples
-    n_pcs = min(n_pcs, mt.cols().count() - sample_to_drop_ht.count())
+    samples_to_drop_num = 0 if sample_to_drop_ht is None else sample_to_drop_ht.count()
+    n_pcs = min(n_pcs, mt.cols().count() - samples_to_drop_num)
     eigenvalues, scores_ht, loadings_ht = run_pca_with_relateds(
         mt, sample_to_drop_ht, n_pcs=n_pcs
     )
@@ -248,7 +236,7 @@ def assign_pops(
 
     :param pop_pca_scores_ht: output table of `_run_pca_ancestry_analysis()`
         with a row field 'scores': array<float64>
-    :param assigned_pop_ht: table with a `population` field. Samples for which
+    :param assigned_pop_ht: table with a `continental_pop` field. Samples for which
         the latter is defined will be used to train the random forest
     :param tmp_bucket: bucket to write checkpoints and intermediate files
     :param min_prob: min probability of belonging to a given population
@@ -272,9 +260,12 @@ def assign_pops(
     if utils.can_reuse(out_ht_path, overwrite):
         return hl.read_table(out_ht_path)
 
-    samples_with_pop_ht = assigned_pop_ht.filter(assigned_pop_ht.population != '')
+    samples_with_pop_ht = assigned_pop_ht.filter(
+        hl.is_defined(assigned_pop_ht.continental_pop) & assigned_pop_ht.continental_pop
+        != ''
+    )
     pop_pca_scores_ht = pop_pca_scores_ht.annotate(
-        training_pop=samples_with_pop_ht[pop_pca_scores_ht.key].population
+        training_pop=samples_with_pop_ht[pop_pca_scores_ht.key].continental_pop
     )
 
     def _run_assign_population_pcs(pop_pca_scores_ht, min_prob):
