@@ -64,11 +64,25 @@ GNOMAD_HGDP_1KG_MT_PATH = (
     'gs://gcp-public-data--gnomad/release/3.1/mt/genomes/'
     'gnomad.genomes.v3.1.hgdp_1kg_subset_dense.mt'
 )
+GNOMAD_HGDP_1KG_TEST_MT_PATH = join(
+    REF_BUCKET, 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_test.mt'
+)
+
 
 NUMBER_OF_HAPLOTYPE_CALLER_INTERVALS = 50
 NUMBER_OF_GENOMICS_DB_INTERVALS = 50
 
 
+# Sample QC output file names
+POP_HT_NAME = 'pop.ht'
+REGRESSED_METRICS_HT_NAME = 'regressed_metrics.ht'
+RELATED_SAMPLES_TO_DROP_HT_NAME = 'related_samples_to_drop.ht'
+
+PCA_EIGENVALUES_HT_NAME = 'pca_eigenvalues.ht'
+PCA_SCORES_HT_NAME = 'pca_scores.ht'
+PCA_LOADINGS_HT_NAME = 'pca_loadings.ht'
+
+
 def init_hail(name: str, local_tmp_dir: str = None):
     """
     Initialize Hail and set up the directory for logs
