@@ -1,8 +1,12 @@
 #!/usr/bin/env python
 
 """
-Generates info.ht, info-split.ht, info.vcf, needed for 
-sample qc and for random forest
+Computes a HT with the typical GATK AS and site-level info fields
+as well as ACs and lowqual fields. Note that this table doesn't 
+split multi-allelic sites.
+
+Generates info.ht, info-split.ht, needed for sample_qc and for 
+random forest jobs.
 """
 
 import logging
@@ -21,7 +25,6 @@ from gnomad.utils.sparse_mt import (
     split_info_annotation,
     split_lowqual_annotation,
 )
-from gnomad.utils.vcf import adjust_vcf_incompatible_types
 
 from joint_calling.utils import file_exists
 from joint_calling import utils, _version
@@ -37,10 +40,6 @@ logger.setLevel(logging.INFO)
     'out_info_ht_path',
     required=True,
 )
-@click.option(
-    '--out-info-vcf',
-    'out_info_vcf_path',
-)
 @click.option(
     '--out-split-info-ht',
     'out_split_info_ht_path',
@@ -67,7 +66,6 @@ logger.setLevel(logging.INFO)
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-statements,missing-function-docstring
     out_info_ht_path: str,
-    out_info_vcf_path: str,
     out_split_info_ht_path: str,
     mt_path: str,
     local_tmp_dir: str,
@@ -80,7 +78,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-stateme
     compute_info(
         mt=all_samples_mt,
         out_ht_path=out_info_ht_path,
-        out_vcf_path=out_info_vcf_path,
         out_split_ht_path=out_split_info_ht_path,
         overwrite=overwrite,
     )
@@ -89,23 +86,17 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-stateme
 def compute_info(
     mt: hl.MatrixTable,
     out_ht_path: str,
-    out_vcf_path: str,
     out_split_ht_path: str,
     overwrite: bool = False,
 ) -> hl.Table:
     """
-    Computes a HT with the typical GATK AS and site-level info fields
-    as well as ACs and lowqual fields.
-    Note that this table doesn't split multi-allelic sites.
     :param mt: full matrix table
     :param out_ht_path: where to write the info Table
-    :param out_vcf_path: if provided, the info Table will be converted to VCF
     :param out_split_ht_path: if provided, in the info Table multiallelics will be split
     and the Table will be written to this file
     :param overwrite: overwrite checkpoints if they exist
     :return: Table with info fields
     """
-    logger.info('Compute info')
     if not overwrite and file_exists(out_ht_path):
         info_ht = hl.read_table(out_ht_path)
     else:
@@ -114,6 +105,8 @@ def compute_info(
         mt = mt.annotate_rows(alt_alleles_range_array=hl.range(1, hl.len(mt.alleles)))
 
         # Compute AS and site level info expr
+        # Note that production defaults have changed:
+        # For new releases, the `RAW_MQandDP` field replaces the `RAW_MQ` and `MQ_DP` fields
         info_expr = get_site_info_expr(
             mt,
             sum_agg_fields=INFO_SUM_AGG_FIELDS,
@@ -191,9 +184,6 @@ def compute_info(
         split_info_ht = split_multiallelic_in_info_table(info_ht)
         split_info_ht.write(out_split_ht_path, overwrite=True)
 
-    if out_vcf_path and (overwrite or not file_exists(out_vcf_path)):
-        hl.export_vcf(adjust_vcf_incompatible_types(info_ht), out_vcf_path)
-
     return info_ht
 
 
